/**************************************************************************
// ADOBE SYSTEMS INCORPORATED
// Copyright  2016 Adobe Systems Incorporated
// All Rights Reserved
//
// NOTICE:  Adobe permits you to use, modify, and distribute this 
// file in accordance with the terms of the Adobe license agreement
// accompanying it.  If you have received this file from a source
// other than Adobe, then your use, modification, or distribution
// of it requires the prior written permission of Adobe.
**************************************************************************/

#ifndef ADOBE_AUDITION_ASDK_MEDIATYPES_H
#define ADOBE_AUDITION_ASDK_MEDIATYPES_H

#include "ASDKTypes.h"

namespace asdk
{
	
	///////////////////////////////////////////
	//
	//
	enum
	{
		// Uninitialized
		kVideoPixelType_Unknown				= 0,
		// ARGB, 8 bits per component, 32 bits per pixel
		// Matches to PrPixelFormat_XRGB_4444_8u in Premiere Pro SDK
		kVideoPixelType_ARGB32				= 1,
		// YUV flavor 1
		// Matches to PrPixelFormat_UYVY_422_8u_601 in Premiere Pro SDK
		kVideoPixelType_YUV_1				= 2,
	};
	typedef asdk::uint32 VideoPixelType;
	
	/////////////////////////////////////////
	//
	//
	enum
	{
		// Full frame
		// Matches to prFieldsNone in Premiere Pro SDK
		kFieldType_Progressive				= 0,
		// Topmost line is first in time
		// Matches to prFieldsUpperFirst in Premiere Pro SDK
		kFieldType_UpperFirst				= 1,
		// Topmost + 1 line is first in time
		// Matches to prFieldsLowerFirst in Premiere Pro SDK
		kFieldType_LowerFirst				= 2,
	};
	typedef asdk::uint32 VideoFieldType;
	
	///////////////////////////////////////////
	//
	//
	enum
	{
		// Normally, a channel label corresponds (roughly) to a speaker position.
		// Other more generic channel labels may be defined in the future.
		kAudioChannelLabel_Discrete					= 0,	// No particular speaker: (e.g. the channel is a discrete mono channel)
		
		// Amio												   WAVEFORMATEXTENSIBLE				Apple CoreAudio								VST 3.6
		// ----------------------------------------------	   -----------------------------	---------------------------------------		------------------
		kAudioChannelLabel_FrontLeft				= 100,	// SPEAKER_FRONT_LEFT				kAudioChannelLabel_Left						kSpeakerL
		kAudioChannelLabel_FrontRight				= 101,	// SPEAKER_FRONT_RIGHT				kAudioChannelLabel_Right					kSpeakerR
		kAudioChannelLabel_FrontCenter				= 102,	// SPEAKER_FRONT_CENTER				kAudioChannelLabel_Center					kSpeakerC
		kAudioChannelLabel_LowFrequency				= 103,	// SPEAKER_LOW_FREQUENCY			kAudioChannelLabel_LFEScreen				kSpeakerLfe
		kAudioChannelLabel_BackLeft					= 104,	// SPEAKER_BACK_LEFT				kAudioChannelLabel_LeftSurround				kSpeakerLs
		kAudioChannelLabel_BackRight				= 105,	// SPEAKER_BACK_RIGHT				kAudioChannelLabel_RightSurround			kSpeakerRs
		kAudioChannelLabel_BackCenter				= 106,	// SPEAKER_BACK_CENTER				kAudioChannelLabel_CenterSurround			kSpeakerCs = kSpeakerS
		kAudioChannelLabel_FrontLeftOfCenter		= 107,	// SPEAKER_FRONT_LEFT_OF_CENTER		kAudioChannelLabel_LeftCenter				kSpeakerLc
		kAudioChannelLabel_FrontRightOfCenter		= 108,	// SPEAKER_FRONT_RIGHT_OF_CENTER	kAudioChannelLabel_RightCenter				kSpeakerRc
		kAudioChannelLabel_SideLeft					= 109,	// SPEAKER_SIDE_LEFT				kAudioChannelLabel_LeftSurroundDirect		kSpeakerSl
		kAudioChannelLabel_SideRight				= 110,	// SPEAKER_SIDE_RIGHT				kAudioChannelLabel_RightSurroundDirect		kSpeakerSr
		kAudioChannelLabel_TopCenter				= 111,	// SPEAKER_TOP_CENTER				kAudioChannelLabel_TopCenterSurround		kSpeakerTc
		kAudioChannelLabel_TopFrontLeft				= 112,	// SPEAKER_TOP_FRONT_LEFT			kAudioChannelLabel_VerticalHeightLeft		kSpeakerTfl
		kAudioChannelLabel_TopFrontRight			= 113,	// SPEAKER_TOP_FRONT_RIGHT			kAudioChannelLabel_VerticalHeightRight		kSpeakerTfr
		kAudioChannelLabel_TopFrontCenter			= 114,	// SPEAKER_TOP_FRONT_CENTER			kAudioChannelLabel_VerticalHeightCenter		kSpeakerTfc
		kAudioChannelLabel_TopBackLeft				= 115,	// SPEAKER_TOP_BACK_LEFT			kAudioChannelLabel_TopBackLeft				kSpeakerTrl
		kAudioChannelLabel_TopBackRight				= 116,	// SPEAKER_TOP_BACK_RIGHT			kAudioChannelLabel_TopBackRight				kSpeakerTrr
		kAudioChannelLabel_TopBackCenter			= 117,	// SPEAKER_TOP_BACK_CENTER			kAudioChannelLabel_TopBackCenter			kSpeakerTrc
		kAudioChannelLabel_FrontLeftWide			= 118,	//									kAudioChannelLabel_LeftWide
		kAudioChannelLabel_FrontRightWide			= 119,	//									kAudioChannelLabel_RightWide
		// Reserved - DO NOT USE					  120-126
		kAudioChannelLabel_LeftHeight				= 127,	//																				kSpeakerTsl
		kAudioChannelLabel_RightHeight				= 128,	//																				kSpeakerTsr
		kAudioChannelLabel_RearSurroundLeft 		= 129,	//									kAudioChannelLabel_RearSurroundLeft			kSpeakerLcs
		kAudioChannelLabel_RearSurroundRight		= 130, 	//									kAudioChannelLabel_RearSurroundRight		kSpeakerRcs
		kAudioChannelLabel_LFE2						= 131,	//									kAudioChannelLabel_LFE2						kSpeakerLfe2
		kAudioChannelLabel_LeftTotal				= 132,	//									kAudioChannelLabel_LeftTotal
		kAudioChannelLabel_RightTotal				= 133,	//									kAudioChannelLabel_RightTotal
		kAudioChannelLabel_Ambisonic_W				= 134,	//									kAudioChannelLabel_Ambisonic_W				kSpeakerW
		kAudioChannelLabel_Ambisonic_X				= 135,	//									kAudioChannelLabel_Ambisonic_X				kSpeakerX
		kAudioChannelLabel_Ambisonic_Y				= 136,	//									kAudioChannelLabel_Ambisonic_Y				kSpeakerY
		kAudioChannelLabel_Ambisonic_Z				= 137,	//									kAudioChannelLabel_Ambisonic_Z				kSpeakerZ
		kAudioChannelLabel_BottomFrontLeft			= 138,	//																				kSpeakerBfl
		kAudioChannelLabel_BottomFrontCenter		= 139,	//																				kSpeakerBfc
		kAudioChannelLabel_BottomFrontRight			= 140,	//																				kSpeakerBfr
		kAudioChannelLabel_ProximityLeft			= 141,	//																				kSpeakerPl
		kAudioChannelLabel_ProximityRight			= 142,	//																				kSpeakerPr
	};
	typedef asdk::uint32 AudioChannelLabel;
	
	
	///////////////////////////////////////////
	//
	//
	typedef asdk::uint32 AudioChannelCount;	// The total number of channels.
	typedef asdk::uint32 AudioChannelIndex;	// A zero-based index into the total number of channels.
	
} // namespace asdk

#endif // ADOBE_AUDITION_ASDK_MEDIATYPES_H
