/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IEDITAUDIOCLIP_H
#define AUDITION_SESSIONSDK_IEDITAUDIOCLIP_H

#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/Session/AudioClipParameters.h"
#include "AuditionSDK/Session/ClipFadeType.h"
#include "AuditionSDK/Session/EffectSlot.h"
#include "AuditionSDK/Session/IEditAudioComponent.h"
#include "AuditionSDK/Session/IEditClipProperties.h"
#include "AuditionSDK/Session/IEditEffectsRack.h"
#include "AuditionSDK/Session/IEditFade.h"
#include "AuditionSDK/Session/IEditStretch.h"
#include "AuditionSDK/Session/IEditVideoFormat.h"

namespace ases
{
	/////////////////////////////////////////
	//
	// Interface to edit clip properties
	//
	class IEditAudioClip
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////
		//
		//set clip properties
		virtual void SetClipFileID(asdk::uint32 inFileID) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipInPoint(asdk::int64 inInPoint) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipDuration(asdk::int64 inDuration) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipStart(asdk::int64 inClipStart) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipHue(asdk::float64 inHue) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipLooped(bool inLooped) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipName(const asdk::uniChar16* inNAme) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipOffline(bool inOffline) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipSelected(bool inSelected) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipZOrder(asdk::int32 inZOrder) = 0;

		//////////////////////////////////////////
		//
		virtual void SetClipSourceChannel(asdk::uint32 inchannelIndex, asdk::int32 inSourceChannel) = 0;

		//////////////////////////////////////////
		//
		virtual void SetLockedInTime(bool inLockedInTime) = 0;

		//////////////////////////////////////////
		//
		virtual IEditFade* CreateFadeIn() = 0; ///< Fails and returns 0 if FadeIn has been created already.

		//////////////////////////////////////////
		//
		virtual IEditFade* CreateFadeOut() = 0; ///< Fails and returns 0 if FadeOut has been created already.

		//////////////////////////////////////////
		//
		virtual IEditStretch* CreateClipStretch() = 0; ///< Fails and returns 0 if stretch has been created already.

		//////////////////////////////////////////
		//
		virtual void SetClipAutoCrossfade(bool inAutoCrossfade) = 0;

		//////////////////////////////////////////
		//
		virtual void SetCrossFadeHeadClipID(asdk::int32 inCrossFadeHeadClipID) = 0;

		//////////////////////////////////////////
		//
		virtual void SetCrossFadeTailClipID(asdk::int32 inCrossFadeTailClipID) = 0;

		//////////////////////////////////////////
		//
		virtual void AddTake(asdk::int64 inTakeTime) = 0;

		////////////////////////////////////////////////////
		//
		virtual void AddEditParameter(
			asdk::uint32	inSlotIndex,	// see EffectSlot enum
			asdk::uint32	inParameterIndex) = 0;

		//////////////////////////////////////////
		// Clip effects
		// Create an effects rack interface
		virtual IEditEffectsRack* GetEditEffectsRack() = 0;

		////////////////////////////////////////////////////
		//
		virtual IEditAudioComponent* GetEditGainComponent() = 0;

		////////////////////////////////////////////////////
		//
		virtual IEditAudioComponent* GetEditMuteComponent() = 0;

		////////////////////////////////////////////////////
		//
		virtual IEditAudioComponent* GetEditOutputComponent() = 0; // See AudioClipParameters.h for clip output parameters

		////////////////////////////////////////////////////
		// Session SDK version 1.2 and later
		// Clips can now carry generic properties which are themselves serialized in XML format. Use this function
		// to get the clips properties which you need to pass a valid XML string to. Refer to IEditClipProperties for the specific XML format.
		//
		virtual IEditClipProperties* GetEditProperties() = 0;

	}; // IEditAudioClip

	typedef asdk::InterfacePtr<IEditAudioClip> IEditAudioClipPtr;


} // namespace ases

#endif // AUDITION_SESSIONSDK_IEDITAUDIOCLIP_H
