/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual
* and technical concepts contained herein are proprietary to  Adobe Systems
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign
* Patents,patents in process,and are protected by trade secret or copyright
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IEDITAUDIOTRACK_H
#define AUDITION_SESSIONSDK_IEDITAUDIOTRACK_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/Session/IEditAudioClip.h"
#include "AuditionSDK/Session/IEditEffectsRack.h"
#include "AuditionSDK/Session/IEditSendList.h"
#include "AuditionSDK/Session/AutomationMode.h"

namespace ases
{

	/////////////////////////////////////////
	//
	//
	class IEditAudioTrack
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////
		//
		// set track properties
		virtual void SetTrackOrder(asdk::uint32 inTrackOrder) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackType(asdk::uint32 inTrackType) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackSelected(bool inSelected) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackHue(asdk::float64 inHue) = 0;
		//////////////////////////////////////////
		// fixed track height
		virtual void SetTrackMinimize(bool inMinimized) = 0;
		//////////////////////////////////////////
		//
		// set track parameters
		virtual void SetTrackName(const asdk::uniChar16* inTrackName) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackHeight(asdk::int32 inTrackHeight) = 0;
		//////////////////////////////////////////
		//
		// set track audio parameters
		virtual void SetTrackChannels(asdk::uint32 inChannels) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackSolo(bool	inSolo) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackArmedForRecord(bool inArmed) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackInputMonitoring(bool inMonitoring) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackSoloSafe(bool	inSoloSafe) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackOutputTrackID(asdk::int32 inOutputTrackID) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackInputPortID(asdk::int32 inInputPortID) = 0;
		//////////////////////////////////////////
		//
		virtual void SetTrackOutputPortID(asdk::int32 inOutputPortID) = 0;

		//////////////////////////////////////////
		//
		virtual void SetTrackIsPhaseInverted(bool inIsPhaseInverted) = 0;

		//////////////////////////////////////////
		//
		virtual void SetTrackIsPreRendered(bool inIsPreRendered) = 0;

		//////////////////////////////////////////
		//
		virtual void SetTrackSumToMono(bool inSumToMono) = 0;

		//////////////////////////////////////////
		//
		virtual void SetTrackPreRenderedFileName(const asdk::uniChar16* inPreRenderedFileName) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// if not exist, Create an clipInfo interface from clipID.
		virtual IEditAudioClip* AddClip(asdk::uint32 inClipID) = 0;

		//////////////////////////////////////////
		// Track effects
		// Create an effects rack interface
		virtual IEditEffectsRack* GetEditEffectsRack() = 0;

		////////////////////////////////////////////////////
		// get the fader component on the track as an effect
		virtual IEditAudioComponent* GetFaderComponent() = 0;

		////////////////////////////////////////////////////
		// get the Mute component on the track as an effect
		virtual IEditAudioComponent* GetMuteComponent() = 0;

		////////////////////////////////////////////////////
		// get the Panner component on the track as an effect
		virtual IEditAudioComponent* GetPannerComponent() = 0;

		////////////////////////////////////////////////////
		//
		virtual IEditAudioComponent* GetEQComponent() = 0;

		////////////////////////////////////////////////////
		//
		virtual void AddEditParameter(
			asdk::uint32	inSlotIndex,
			asdk::uint32	inParameterIndex) = 0;

		////////////////////////////////////////////////////
		//
		virtual void SetAutomationLaneOpenState(bool inOpenState) = 0;

		////////////////////////////////////////////////////
		//
		virtual void SetAutomationMode(AutomationMode inAutomationMode) = 0;

		////////////////////////////////////////////////////
		//
		virtual IEditSendList* GetEditSendList() = 0;

		////////////////////////////////////////////////////
		//
		virtual void SetVisible(bool inVisible) = 0;	///< If isVisible is true, the track will be shown in the UI
	}; // IEditAudioTrack

	typedef asdk::InterfacePtr<IEditAudioTrack> IEditAudioTrackPtr;

} // namespace ases

#endif // AUDITION_SESSIONSDK_IEDITAUDIOTRACK_H
