/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IEDITSESSION_H
#define AUDITION_SESSIONSDK_IEDITSESSION_H

#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/Session/IEditAudioTrack.h"
#include "AuditionSDK/Session/IEditClipGroup.h"
#include "AuditionSDK/Session/IEditClipProperties.h"
#include "AuditionSDK/Session/IEditFileInfo.h"
#include "AuditionSDK/Session/IEditMarkerInfo.h"
#include "AuditionSDK/Session/IEditMetronomeInfo.h"
#include "AuditionSDK/Session/IEditProperties.h"
#include "AuditionSDK/Session/IEditVideoTrack.h"
#include "AuditionSDK/Session/ISessionError.h"

namespace ases
{
	////////////////////////////////////////////
	//
	//
	class IEditSession
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////////////////////////////////////////
		// Get an interface for setting extended error information.
		virtual ISessionError* GetErrorInterface() = 0;
		
		//////////////////////////////////////////////////////////////////////////////
		// call progress
		// to report specific progress, either pass a progress code (use the SessionProgress enum), or pass specific text
		// return true of ok, false means user cancel
		virtual bool UpdateProgress(asdk::int32 inCount, asdk::int32 inTotal, asdk::int32 inProgressCode = 0, const asdk::uniChar16* inText = NULL) = 0;
		
		//////////////////////////////////////////////////////////////////////////////
		////// session
		//
		virtual void SetSessionName(const asdk::uniChar16* inName) = 0;
		
		////////////////////////
		//
		virtual void SetFormatDescription(const asdk::uniChar16* inFormatDescription) = 0;

		////////////////////////
		//
		virtual void SetSampleRate(asdk::uint32 inSampleRate) = 0;
		
		////////////////////////
		//
		virtual void SetChannelCount(asdk::uint32 inChannels) = 0;
		
		////////////////////////
		//
		virtual void SetDuration(asdk::int64 inDuration) = 0;
		
		////////////////////////
		//
		virtual void SetBitDepth(asdk::uint32 inBitDepth) = 0;
		
		//////////////////////////
		// files
		virtual IEditFileInfo* AddFileInfo(asdk::uint32 inFileID) = 0;

		//////////////////////////////////////////
		//
		// Device
		virtual void SetInputDeviceUID(const asdk::uniChar16* inUID) = 0;

		//////////////////////////////////////////
		// 
		virtual void AddInputPort(
			asdk::int32				inPortID,
			const asdk::uniChar16*	inPortName) = 0;

		//////////////////////////////////////////
		//
		virtual void SetOutputDeviceUID(const asdk::uniChar16* inUID) = 0;

		//////////////////////////////////////////
		// 
		virtual void AddOutputPort(
			asdk::int32				inPortID,
			const asdk::uniChar16*	inPortName) = 0;

		//////////////////////////////////////////////////////////////////////////////
		//
		virtual IEditVideoTrack* AddVideoTrack(asdk::uint32 inTrackID) = 0;

		//////////////////////////////////////////////////////////////////////////////
		//
		virtual IEditAudioTrack* AddAudioTrack(asdk::uint32 inTrackID) = 0;
		
		////////////////////////
		// session state
		virtual void SetSelectionState(
			asdk::int64 inSelectionStart,
			asdk::int64 inSelectionLength) = 0;
			
		////////////////////////
		//
		virtual void SetCTIPosition(asdk::int64 inPos) = 0;
		
		////////////////////////
		//
		virtual void SetViewState(
			asdk::int64 inHorizontalViewStart,
			asdk::int64 inHorizontalViewLength,
			asdk::int32 inTrackControlsWidth,
			asdk::int32 inVerticalScrollOffset) = 0;

		////////////////////////
		//
		virtual void SetTimeFormatState(
			asdk::int32		inTimeFormat,
			asdk::int32		inTimeCodeFrameRate,
			bool			inTimeCodeNTSC,
			bool			inTimeCodeDropFrame,
			asdk::int32		inCustomFrameRate) = 0;

		//////////////////////////////////////////
		//
		virtual void SetMixingState(
			bool			inPanModeLogarithmic,
			double			inPanPower) = 0;

		////////////////////////
		//
		virtual void SetIsFollowingTimeDefaults(bool inLinkToDefault) = 0;

		////////////////////////
		//
		virtual void SetBeatInfo(
			double			inBeatsPerMinute,
			asdk::int32		inBeatsPerBar,
			asdk::int32		inNoteLen,
			asdk::int32		inTicksPerQuarterNote) = 0;

		////////////////////////
		//
		virtual void SetSMPTEStartTimeOffset(asdk::int64 inStart) = 0;

		////////////////////////
		// session metadata
		virtual void SetMetadata(const asdk::uniChar16*  inMetadata) = 0;
 		
		//////////////////////////
		//
		// markers
		virtual IEditMarkerInfo* AddMarkerInfo() = 0;

		//////////////////////////
		//
		// asset file path
		virtual asdk::IString*  GetAssetFolderPath() const = 0;

		//////////////////////////////////////////
		//
		// helper utility function to translate from a normalized gain value to
		// Audition's volume component value.
		virtual asdk::float32 TranslateNormalizedGainToVolumeComponentVal(asdk::float32 inNormalizedGainValue) const = 0;

		//////////////////////////////////////////
		//
		// helper utility function to translate from URI to Path 
		//
		virtual asdk::IString*  TranslateURIToPath(const asdk::uniChar16* inURI) const = 0;

		//////////////////////////////////////////
		//
		// helper utility function to translate from Path to URI
		//
		virtual asdk::IString*  TranslatePathToURI(const asdk::uniChar16* inURI) const = 0;

		//////////////////////////////////////////////////////////////////////////////
		//
		virtual IEditClipGroup* AddClipGroup(asdk::uint32 inClipGroupID) = 0;
		
		//////////////////////////////////////////////////////////////////////////////
		//
		virtual IEditMetronomeInfo* AddMetronomeInfo() = 0;

		//////////////////////////////////////////
		// Added in Session SDK version 1.3
		// general session properties
		virtual IEditProperties* AddProperties() = 0;

	}; // IEditSession

	typedef asdk::InterfacePtr<IEditSession> IEditSessionPtr;

} // namespace ases

#endif // AUDITION_SESSIONSDK_IEDITSESSION_H
