/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IQUERYAUDIOCLIP_H
#define AUDITION_SESSIONSDK_IQUERYAUDIOCLIP_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/Session/IQueryAudioComponent.h"
#include "AuditionSDK/Session/IQueryEffectsRack.h"
#include "AuditionSDK/Session/IQueryFade.h"
#include "AuditionSDK/Session/IQueryClipProperties.h"
#include "AuditionSDK/Session/IQueryStretch.h"
#include "AuditionSDK/Session/IQueryVideoFormat.h"
#include "AuditionSDK/Session/ClipFadeType.h"
#include "AuditionSDK/Session/AudioClipParameters.h"

namespace ases
{
	/////////////////////////////////////////
	//
	//
	class IQueryAudioClip
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetClipID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetClipFileID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int64 GetClipInPoint() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int64 GetClipDuration() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int64 GetClipStart() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::float64 GetClipHue() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetClipLooped() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::IString* GetClipName() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetClipOffline() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetClipSelected() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetClipZOrder() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetClipChannelCount() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetClipSourceChannel(asdk::uint32 inChannelIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetClipLockedInTime() const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryFade* GetFadeIn() const = 0;  ///< May return 0

		//////////////////////////////////////////
		//
		virtual IQueryFade* GetFadeOut() const = 0; ///< May return 0

		//////////////////////////////////////////
		//
		virtual IQueryStretch* GetClipStretch() const = 0; ///< May return 0

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetCrossFadeHeadClipID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetCrossFadeTailClipID() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetClipAutoCrossfade() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int64 GetTake(asdk::uint32 inTakeIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetTakeCount() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetEditParameterCount() const = 0;

		//////////////////////////////////////////
		//
		virtual void GetEditParameter(
			asdk::uint32	inEditParameterIndex,
			asdk::uint32&	outSlotIndex,
			asdk::uint32&	outParameterIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryEffectsRack* GetClipEffectsRack() const = 0;

		////////////////////////////////////////////////////
		//
		virtual IQueryAudioComponent* GetQueryGainComponent() const = 0;

		////////////////////////////////////////////////////
		//
		virtual IQueryAudioComponent* GetQueryMuteComponent() const = 0;

		////////////////////////////////////////////////////
		//
		virtual IQueryAudioComponent* GetQueryOutputComponent() const = 0;	// See AudioClipParameters.h for clip output parameters
		
		//////////////////////////////////////////////////////////////////////////
		// Session SDK version 1.2 and later
		// Clips can now carry generic properties which are themselves serialized in XML Format. Use this function
		// to get the clips properties which can return a pre serialized XML string. Refer to IQueryProperties for the specific XML format.
		virtual IQueryClipProperties* GetQueryProperties() const = 0;

	}; // IQueryAudioClip

	typedef asdk::InterfacePtr<IQueryAudioClip> IQueryAudioClipPtr;

} // namespace ases

#endif // AUDITION_SESSIONSDK_IQUERYAUDIOCLIP_H
