/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual
* and technical concepts contained herein are proprietary to  Adobe Systems
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign
* Patents,patents in process,and are protected by trade secret or copyright
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IQUERYAUDIOTRACK_H
#define AUDITION_SESSIONSDK_IQUERYAUDIOTRACK_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKString.h"
#include "AuditionSDK/Session/IQueryAudioClip.h"
#include "AuditionSDK/Session/IQueryEffectsRack.h"
#include "AuditionSDK/Session/IQuerySendList.h"
#include "AuditionSDK/Session/IQueryAudioChannelAssignmentInfo.h"
#include "AuditionSDK/Session/AutomationMode.h"

namespace ases
{
	/////////////////////////////////////////
	//
	//
	class IQueryAudioTrack
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////
		//
		// get properties
		virtual asdk::uint32 GetTrackID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetTrackOrder() const = 0;

		//////////////////////////////////////////
		//
		// Return Values:
		// Video	= 0		// ***Audio Tracks should never have this type
		// Audio	= 1
		// Bus		= 2
		// Master	= 3
		//
		virtual asdk::uint32 GetTrackType() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackSelected() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::float64 GetTrackHue() const = 0;

		//////////////////////////////////////////
		//
		// get parameters
		virtual asdk::IString* GetTrackName() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetTrackHeight() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackMinimize() const = 0;

		//////////////////////////////////////////
		//
		// get audio params
		virtual asdk::uint32 GetTrackChannels() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackSolo() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackArmedForRecord() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackInputMonitoring() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackSoloSafe() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetTrackOutputTrackID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetTrackInputPortID() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::int32 GetTrackOutputPortID() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackIsPhaseInverted() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackIsPreRendered() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetTrackSumToMono() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::IString* GetTrackPreRenderedFileName() const = 0;

		//////////////////////////////////////////
		//
		// track clips
		virtual asdk::uint32 GetTrackClipCount() const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Get an clipInfo interface from clipindex.
		virtual IQueryAudioClip* GetClip(asdk::uint32 inClipIndex) const = 0;

		//////////////////////////////////////////
		// Track effects
		// Get an effects rack interface
		virtual IQueryEffectsRack* GetEffectsRack() const = 0;

		////////////////////////////////////////////////////
		// get the fader component on the track as an effect
		virtual IQueryAudioComponent* GetFaderComponent() const = 0;

		////////////////////////////////////////////////////
		// get the Mute component on the track as an effect
		virtual IQueryAudioComponent* GetMuteComponent() const = 0;

		////////////////////////////////////////////////////
		// get the Panner component on the track as an effect
		virtual IQueryAudioComponent* GetPannerComponent() const = 0;

		////////////////////////////////////////////////////
		//
		virtual IQueryAudioComponent* GetEQComponent() const = 0;


		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetEditParameterCount() const = 0;

		//////////////////////////////////////////
		//
		virtual void GetEditParameter(
			asdk::uint32	inEditParameterIndex,
			asdk::uint32&	outSlotIndex,
			asdk::uint32&	outParameterIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetAutomationLaneOpenState() const = 0;

		//////////////////////////////////////////
		//
		virtual AutomationMode GetAutomationMode() const = 0;

		//////////////////////////////////////////
		//
		virtual IQuerySendList* GetQuerySendList() const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetVisible() const = 0;	///< Returns true if the track is visible in the UI, false if hidden

		//////////////////////////////////////////
		// Added in Session SDK version 1.3
		virtual IQueryAudioChannelAssignmentInfo* GetTrackOutputChannelAssigment() const = 0;

	}; // QueryTrack

	typedef asdk::InterfacePtr<IQueryAudioTrack> IQueryAudioTrackPtr;

} // namespace ases

#endif // AUDITION_SESSIONSDK_IQUERYAUDIOTRACK_H
