/*************************************************************************
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2015 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains
* the property of Adobe Systems Incorporated and its suppliers,
* if any.  The intellectual and technical concepts contained
* herein are proprietary to Adobe Systems Incorporated and its
* suppliers and are protected by all applicable intellectual property
* laws, including trade secret and copyright laws.
* Dissemination of this information or reproduction of this material
* is strictly forbidden unless prior written permission is obtained
* from Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IQUERYCLIPPROPERTIES_H
#define AUDITION_SESSIONSDK_IQUERYCLIPPROPERTIES_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKString.h"

namespace ases
{

	/////////////////////////////////////////
	//interface to get generic clip properties
	//
	class IQueryClipProperties
		:
		public asdk::InterfaceBase
	{
	public:
		//////////////////////////////////////////
		// Set generic properties with a JSON string that adheres to the following template format that closely matches a JSON schmema definition by itself
		// String ins <> are placeholders for real property or valye names
		//
		//	{
		//		"<PropertyName>": {
		//		"type": "tree::any", /* type used for properties and sub properties */
		//		"value": {
		//			"<FloatValueName>": {
		//				"type": "float",
		//				"value": <string_value>
		//			},
		//			"<BoolValueName>": {
		//				"type": "float",
		//				"value": <bool_value>
		//			},
		//			"<IntValueName>": {
		//				"type": "std::uint32_t",
		//				"value": <int_value>
		//			},
		//			"<ArrayValueName>": {
		//			"type": "array::std::int64_t",
		//			"value": [
		//				<array_values>
		//				]
		//			},
		//			"<StringValueName>": {
		//				"type": "UTF16String",
		//				"value": "<string_value"
		//			},...
		//		}
		//	}
		//
		virtual asdk::IString* GetJSONPropertiesFragment() const = 0;
		
		//////////////////////////////////////////
		//
		virtual bool IsEmpty() const = 0;

	}; // IQueryProperties

	typedef asdk::InterfacePtr<IQueryClipProperties> IQueryClipPropertiesPtr;

} // namespace ases

#endif // AUDITION_SESSIONSDK_IQUERYCLIPPROPERTIES_H
