/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_IQUERYSESSION_H
#define AUDITION_SESSIONSDK_IQUERYSESSION_H

#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/Session/IQueryAudioChannelLayoutInfo.h"
#include "AuditionSDK/Session/IQueryAudioTrack.h"
#include "AuditionSDK/Session/IQueryClipGroup.h"
#include "AuditionSDK/Session/IQueryFileInfo.h"
#include "AuditionSDK/Session/IQueryMarkerInfo.h"
#include "AuditionSDK/Session/IQueryMetronomeInfo.h"
#include "AuditionSDK/Session/IQueryProperties.h"
#include "AuditionSDK/Session/IQueryVideoTrack.h"
#include "AuditionSDK/Session/ISessionError.h"

namespace ases
{
	///////////////////////////////////////////
	//
	//
	class IQuerySession
		:
		public asdk::InterfaceBase
	{
	public:

		//////////////////////////////////////////
		// Get an interface for setting extended error information.
		virtual ISessionError* GetErrorInterface() = 0;

		//////////////////////////////////////////
		// Get the version of the session interface used by the host.
		virtual void GetHostInterfaceVersion(
			asdk::int32& outSessionInterfaceVersionMajor, 
			asdk::int32& outSessionInterfaceVersionMinor) const = 0;
			
		//////////////////////////////////////////
		// call progress
		// to report specific progress, either pass a progress code (use the SessionProgress enum), or pass specific text
		// return true of ok, false means user cancel
		virtual bool UpdateProgress(asdk::int32 inCount, asdk::int32 inTotal, asdk::int32 inProgressCode = 0, const asdk::uniChar16* inText = NULL) = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::IString* GetSessionName() const = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::IString* GetFormatDescription() const = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetSampleRate() const = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetChannelCount() const = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::int64 GetDuration() const = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetBitDepth() const = 0;

		// files
		virtual asdk::uint32 GetFileCount() const = 0;
		
		//////////////////////////////////////////
		//
		virtual IQueryFileInfo* GetFileInfo(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		//
		// Device
		virtual asdk::IString* GetInputDeviceUID() const = 0;

		//////////////////////////////////////////
		// 
		virtual asdk::uint32 GetInputPortCount() const = 0;

		//////////////////////////////////////////
		// 
		virtual asdk::int32 GetInputPortID(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		// 
		virtual asdk::IString* GetInputPortName(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::IString* GetOutputDeviceUID() const = 0;	

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetOutputPortCount() const = 0;

		//////////////////////////////////////////
		// 
		virtual asdk::int32 GetOutputPortID(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		// 
		virtual asdk::IString* GetOutputPortName(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetVideoTrackCount() const = 0;
		
		//////////////////////////////////////////
		//
		virtual IQueryVideoTrack* GetVideoTrack(asdk::uint32 inTrackIndex) = 0;
		
		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetAudioTrackCount() const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryAudioTrack* GetAudioTrack(asdk::uint32 inTrackIndex) = 0;
		
		//////////////////////////////////////////
		//
		// session state
		virtual void GetSelectionState(
			asdk::int64* outSelectionStart,
			asdk::int64* outSelectionLength) const = 0;

		//////////////////////////////////////////
		//
		virtual void GetCTIPosition(asdk::int64* outPos) const = 0;
		
		//////////////////////////////////////////
		//
		virtual void GetViewState(
			asdk::int64* outHorizontalViewStart,
			asdk::int64* outHorizontalViewLength,
			asdk::int32* outTrackControlsWidth,
			asdk::int32* outVerticalScrollOffset) const = 0;

		//////////////////////////////////////////
		//
		virtual void GetTimeFormatState(
			asdk::int32*	outTimeFormat,
			asdk::int32*	outTimeCodeFrameRate,
			bool*			outTimeCodeNTSC,
			bool*			outTimeCodeDropFrame,
			asdk::int32*	outCustomFrameRate) const = 0;

		//////////////////////////////////////////
		//
		virtual void GetMixingState(
			bool*			outPanModeLogarithmic,
			double*			outPanPower) const = 0;

		//////////////////////////////////////////
		//
		virtual bool GetIsFollowingTimeDefaults() const = 0;

		//////////////////////////////////////////
		//
		virtual void GetBeatInfo(
			double*			outBeatsPerMinute,
			asdk::int32*	outBeatsPerBar,
			asdk::int32*	outNoteLen,
			asdk::int32*	outTicksPerQuarterNote) const = 0;
			
		//////////////////////////////////////////
		//
		virtual void GetSMPTEStartTimeOffset(asdk::int64* outStart) const = 0;

		//////////////////////////////////////////
		//
		// session metadata
		virtual asdk::IString* GetMetadata() const = 0;

		//////////////////////////////////////////
		//
		// markers
		virtual asdk::uint32 GetMarkerCount() const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryMarkerInfo* GetMarkerInfo(asdk::uint32 inIndex) const = 0;
		
		//////////////////////////////////////////
		//
		// helper utility function to translate from Audition's volume component value
		// to a normalized gain value.
		virtual asdk::float32 TranslateVolumeComponentValToNormalizedGain(asdk::float32 inVolumeComponentValue) const = 0;

		//////////////////////////////////////////
		//
		// (only applicable for OMF session exports)
		virtual bool ShouldEmbedFiles() const = 0;

		//////////////////////////////////////////
		//
		virtual asdk::uint32 GetClipGroupCount() const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryClipGroup* GetClipGroup(asdk::uint32 inIndex) const = 0;

		//////////////////////////////////////////
		//
		virtual IQueryMetronomeInfo* GetMetronomeInfo() const = 0;
		
		//////////////////////////////////////////
		// Added in Session SDK version 1.3
		virtual IQueryAudioChannelLayoutInfo* GetChannelLayoutInfo() const = 0;

		//////////////////////////////////////////
		// Added in Session SDK version 1.3
		// general session properties
		virtual IQueryProperties* GetProperties() const = 0;

	}; // IQuerySession
	
	typedef asdk::InterfacePtr<IQuerySession> IQuerySessionPtr;
	
	
} // namespace ases

#endif // AUDITION_SESSIONSDK_IQUERYSESSION_H
