/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_ISESSIONERROR_H
#define AUDITION_SESSIONSDK_ISESSIONERROR_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"
#include "AuditionSDK/ASDKString.h"

namespace ases
{

	////////////////////////////////////////////////////////////////////////////////
	// Used for commands for which extended error information needs to be returned.
	class ISessionError
		:
		public asdk::InterfaceBase
	{
	public:
		
		//////////////////////////////////////////////////////////////////////////////
		// Set an error using a pre-defined error code.  (Audition will translate this into an error string)
		// For this error, use the SessionInterfaceReturnCode codes
		virtual void SetErrorCode(asdk::int32 inErrorCode) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Set a human-readable error string using a UTF16 string.
		virtual void SetCustomErrorString(const asdk::uniChar16* inString) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Get the human-readable error string in UTF16 format.
		virtual asdk::IString* GetErrorString() const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Find out if an an error string has been set.
		virtual bool HasErrorString() const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Set a warning using a pre-defined warning code.  (Audition will translate this into a warning string)
		// For this, use the WarningCode codes defined below...
		virtual void AddWarningCode(asdk::int32 inWarningCode) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Set a human-readable warning string using a UTF16 string.
		virtual void AddCustomWarningString(const asdk::uniChar16* inWarning) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Get a preivously added human-readable warning string in UTF16 format.
		// The warning index should be from 0 to GetWarningCount() - 1.
		virtual asdk::IString* GetWarningString(asdk::int32 inWarningIndex) const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Gets the count of warnings that have been added.
		virtual asdk::int32 GetWarningCount() const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Clear all previously added warnings.
		virtual void ClearWarnings() = 0;
		
	}; // ISessionError


	typedef asdk::InterfacePtr<ISessionError> ISessionErrorPtr;
	

	enum WarningCode
	{
		kWarningCode_GeneralWarning			= 200
	};


	enum SessionProgress
	{
		kSessionProgress_General					= 0,		// with this, the plugin can pass in their own text
		
		kSessionProgress_ConvertingAutomationData	= 1,		// 1-3 are some General-Purpose Progress Strings
		kSessionProgress_ConvertingClips			= 2,		//     that will be localized.
		kSessionProgress_ConvertingTracks			= 3
	};

} // namespace ases

#endif // AUDITION_SESSIONSDK_ISESSIONERROR_H
