/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_ISESSIONGETPLUGININFO_H
#define AUDITION_SESSIONSDK_ISESSIONGETPLUGININFO_H

#include "AuditionSDK/ASDKTypes.h"
#include "AuditionSDK/ASDKInterface.h"

namespace ases
{

	///////////////////////////////////////////////////////////////////////////////////////////////////
	// Used for kSessionInterfaceCommand_GetSessionInfo, Getting information about this plug-in.
	class ISessionGetPlugInInfo
		:
		public asdk::InterfaceBase
	{
	public:

		//////////////////////////////////////////////////////////////////////////////
		// Set the version of this interface used by this plug-in.
		// Pass kSesxInterfaceVersionMajor and kSesxInterfaceVersionMinor so the host knows which version of the
		// session interface this plug-in is using.
		virtual void SetPluginInterfaceVersion(
			asdk::int32 inSessionInterfaceVersionMajor, 
			asdk::int32 inSessionInterfaceVersionMinor) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Get the version of the session interface used by the host.
		virtual void GetHostInterfaceVersion(
			asdk::int32& outSessionInterfaceVersionMajor, 
			asdk::int32& outSessionInterfaceVersionMinor) const = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Set a unique GUID string, formatted like "3D3B5917-EA4E-463E-B79A-1F6F1CED323E" to identify this plug-in,
		// And give a description of the overall plug-in.  (Individual format descriptions are set using AddInputFormat and AddOutputFormat.)
		// PLEASE, make the ID unique.  
		virtual void SetPluginID(
			const asdk::int8*		inSessionPluginID, 
			const asdk::uniChar16*	inPluginDescription) = 0;

		// Set the description of a format supported for reading, with its file extensions such as sesx", "ses", etc.
		// If the list of extensions is long, use inExtensionListUiOverride to provide a description used in the file UI.
		// Call this for each input format supported.
		virtual void AddImportFormat(
			const asdk::uniChar16*	inFormatDescription, 
			const asdk::uniChar16**	inExtensions,
			asdk::uint32			inNumExtensions) = 0;

		//////////////////////////////////////////////////////////////////////////////
		// Set the description of a format supported for writing, with its file extensions such as "sesx", "ses", etc.
		// Call this for each output format supported.
		virtual void AddExportFormat(
			const asdk::uniChar16*	inFormatDescription, 
			const asdk::uniChar16**	inExtensions,
			asdk::uint32			inNumExtensions) = 0;
			
		//////////////////////////////////////////////////////////////////////////////
		// Get the host's preferences folder
		//
		//	Session SDK version 1.1 and later
		//
		virtual asdk::IString* GetHostPreferencesFolder() const = 0;
		
		//////////////////////////////////////////////////////////////////////////////
		// Get the host's log folder
		//
		//	Session SDK version 1.1 and later
		//
		virtual asdk::IString* GetHostLogFolder() const = 0;
		
	}; // ISessionGetPlugInInfo

	typedef asdk::InterfacePtr<ISessionGetPlugInInfo> ISessionGetPlugInInfoPtr;
	
} // namespace ases

#endif // AUDITION_SESSIONSDK_ISESSIONGETPLUGININFO_H
