/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2010 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_OMFSTRINGS_H
#define AUDITION_SESSIONSDK_OMFSTRINGS_H

#include "AuditionSDK/ASDKTypes.h"

namespace ases
{
	// Errors are fatal conditions where the operation
	// is aborted, and does not continue.
	enum OMFStringID
	{
		/*** Implementation-Specific Error Codes ***/
		kSessionError_OMF_NotOMF	= 3000,		//	This is not an OMFI file.
		kSessionError_OMF_CreateFileInfoError,	//	Could not create file info.
		kSessionError_OMF_NoSourceFiles,		//	There are no source files.
		kSessionError_OMF_UnsupportedBitDepth,	//	Unsupported bit depth.
		kSessionError_OMF_UnsupportedSampleRate,//	Unsupported sample rate.
		kSessionError_OMF_NoAudioTracks,		//	This OMF file does not contain any audio tracks.
		kSessionError_OMF_OpenFileError,		//	Unable to open a required file.
		kSessionError_OMF_BitDepthMismatch,		//	File bit depth does not match sequence.
		kSessionError_OMF_InvalidFileID,		//	Invalid 'FileID' in sequence.

		/*** 1.0 COMPATIBILITY ONLY Error Codes ***/
		kSessionError_OM_ERR_BADOBJ,			//	OMFI_ERR: Null OMFI/Bento object
		kSessionError_OM_ERR_INULLMOBIDPTR,		//	OMFI_ERR(Import): NULL Mob ID pointer in GetNthMediaDesc/SetMediaDesc
		kSessionError_OM_ERR_INULLMTPTR,		//	OMFI_ERR(Import): NULL omfMediaType_t pointer in GetNthMediaDesc
		kSessionError_OM_ERR_INULLDESCPTR,		//	OMFI_ERR(Import): NULL descriptor pointer in GetNthMediaDesc
		kSessionError_OM_ERR_IBADMEDIAINDEX,	//	OMFI_ERR(Import): Input OMFI file does not have enough media objects
		kSessionError_OM_ERR_LRC_DISABLED,		//	OMFI_ERR: LRC codec disabled
		kSessionError_OM_ERR_LRC_BADSAMPLESIZE,	//	OMFI_ERR: Only 16 bit samples supported for LRC
		kSessionError_OM_ERR_LRC_MONOONLY,		//	OMFI_ERR: Only one channel audio supported for LRC
		kSessionError_OM_ERR_BADSESSION,		//	OMFI_INTERNAL_ERR: Bad Bento Session operation
		kSessionError_OM_ERR_INTERNAL_BADOBJ,	//	OMFI_INTERNAL_ERR: Error creating OMFI/Bento object
		kSessionError_OM_ERR_BADSAMPLEOFFSET,	//	OMFI_ERR: Sample Index offset out of range

		/*** SESSION/FILE Error Codes ***/
		/* Session Error Codes */
		kSessionError_OM_ERR_BAD_SESSION,		//	OMFI_ERR: Bad Session Handle
		kSessionError_OM_ERR_BADSESSIONOPEN,	//	OMFI_ERR: Container Session open failed
		kSessionError_OM_ERR_BADSESSIONMETA,	//	OMFI_ERR: Container Session meta-handler operation failed
		kSessionError_OM_ERR_BADSESSIONCLOSE,	//	OMFI_ERR: Container Session close failed
		kSessionError_OM_ERR_BADCONTAINER,		//	OMFI_ERR: Cannot find Bento container
		/* File Error Codes */
		kSessionError_OM_ERR_FILEREV_NOT_SUPP,	//	OMFI_ERR: OMFI File Revision > 2.0 not supported
		kSessionError_OM_ERR_FILEREV_DIFF,		//	OMFI_ERR: Files must have same file revisions
		kSessionError_OM_ERR_BADOPEN,			//	OMFI_ERR: Cannot open file
		kSessionError_OM_ERR_BADCLOSE,			//	OMFI_ERR: Cannot close file
		kSessionError_OM_ERR_BAD_FHDL,			//	OMFI_ERR: Bad File Handle
		kSessionError_OM_ERR_BADHEAD,			//	OMFI_ERR: Invalid OMFI HEAD object
		kSessionError_OM_ERR_NOBYTEORDER,		//	OMFI_ERR: No File Byte Order Specified
		kSessionError_OM_ERR_INVALID_BYTEORDER,	//	OMFI_ERR: Invalid byte order
		kSessionError_OM_ERR_NOTOMFIFILE,		//	OMFI_ERR: Invalid OMFI file
		kSessionError_OM_ERR_WRONG_FILETYPE,	//	OMFI_ERR: Invalid file type (Raw vs. OMFI)
		kSessionError_OM_ERR_WRONG_OPENMODE,	//	OMFI_ERR: File opened in wrong mode (readonly vs. readwrite)
		kSessionError_OM_ERR_CONTAINERWRITE,	//	OMFI_ERR: Error writing to container media (Possibly media is full).
		kSessionError_OM_ERR_FILE_NOT_FOUND,	//	OMFI_ERR: File not found.
		/* Class Dictionary Error Codes */
		kSessionError_OM_ERR_CANNOT_SAVE_CLSD,	//	OMFI_ERR: Error updating the class dictionary in the OMFI file
		kSessionError_OM_ERR_CANNOT_LOAD_CLSD,	//	OMFI_ERR: Error loading the class dictionary from the file
		kSessionError_OM_ERR_FILE_REV_200,		//	OMFI_ERR: Please use toolkit revision 2.0.1 or later to write 2.x compliant files
		kSessionError_OM_ERR_NEED_PRODUCT_IDENT,//	OMFI_ERR: You must supply a product identification struct when creating or updating files

		/*** MEDIA Error Codes ***/
		/* General Media Error Codes */
		kSessionError_OM_ERR_DESCSAMPRATE,		//	OMFI_ERR: Error getting sample rate from file descriptor
		kSessionError_OM_ERR_SOURCEMOBLIST,		//	OMFI_ERR: Error processing source mob list
		kSessionError_OM_ERR_DESCLENGTH,		//	OMFI_ERR: Error getting length from file descriptor
		kSessionError_OM_ERR_INTERNAL_MDO,		//	OMFI_ERR: Internal Media Data system not initialized
		kSessionError_OM_ERR_3COMPONENT,		//	OMFI_ERR: Only 3-component video allowed in OMF files
		kSessionError_OM_ERR_INTERNAL_CORRUPTVINFO,	//	OMFI_INTERNAL_ERR: Corrupt Video Info Structure
		kSessionError_OM_ERR_ONESAMPLEREAD,		//	OMFI_ERR: Only one sample allowed for reading compressed data
		kSessionError_OM_ERR_ONESAMPLEWRITE,	//	OMFI_ERR: Only one sample allowed for writing compressed data
		kSessionError_OM_ERR_DECOMPRESS,		//	OMFI_ERR: Software Decompression Failed
		kSessionError_OM_ERR_NODATA,			//	OMFI_ERR: No data read
		kSessionError_OM_ERR_SMALLBUF,			//	OMFI_ERR: Sample too large to fit in given buffer
		kSessionError_OM_ERR_INTERN_TOO_SMALL,	//	OMFI_ERR: Buffer is not large enough to hold data
		kSessionError_OM_ERR_INTERNAL_UNKNOWN_LOC,	//	OMFI_ERR: Unknown locator type
		kSessionError_OM_ERR_TRANSLATE,			//	OMFI_ERR: Can't translate to expected memory format
		kSessionError_OM_ERR_EOF,				//	OMFI_ERR: End of file
		kSessionError_OM_ERR_BADCOMPR,			//	OMFI_ERR: Unrecognized compression type in OMF file
		kSessionError_OM_ERR_BADPIXFORM,		//	OMFI_ERR: Unrecognized pixel format in OMF file
		kSessionError_OM_ERR_BADLAYOUT,			//	OMFI_ERR: Unrecognized frame layout in OMF file
		kSessionError_OM_ERR_COMPRLINESWR,		//	OMFI_ERR: omfWriteLines not allowed with compression
		kSessionError_OM_ERR_COMPRLINESRD,		//	OMFI_ERR: omfReadLines not allowed with compression
		kSessionError_OM_ERR_BADMEDIATYPE,		//	OMFI_ERR: Unrecognized Media Type
		kSessionError_OM_ERR_BADDATAADDRESS,	//	OMFI_ERR: Null data address for transfer operation
		kSessionError_OM_ERR_BAD_MDHDL,			//	OMFI_ERR: Bad Media Handle
		kSessionError_OM_ERR_MEDIA_NOT_FOUND,	//	OMFI_ERR: Cannot locate media data
		kSessionError_OM_ERR_ILLEGAL_MEMFMT,	//	OMFI_ERR: Illegal memory format code
		kSessionError_OM_ERR_ILLEGAL_FILEFMT,	//	OMFI_ERR: Illegal file format code
		kSessionError_OM_ERR_SWABBUFSIZE,		//	OMFI_ERR: Invalid swab buffer size
		kSessionError_OM_ERR_MISSING_SWAP_PROC,	//	OMFI_ERR: Missing stream swap proc
		kSessionError_OM_ERR_NULL_STREAMPROC,	//	OMFI_ERR: A Stream Callback is NULL
		kSessionError_OM_ERR_NULLBUF,			//	OMFI_ERR: Null transfer buffer
		kSessionError_OM_ERR_SWAP_SETUP,		//	OMFI_ERR: Need to set up file & memory format before calling this function
		kSessionError_OM_ERR_INVALID_FILE_MOB,	//	OMFI_ERR: Invalid file mob reference
		kSessionError_OM_ERR_SINGLE_CHANNEL_OP,	//	OMFI_ERR: Operation not valid on multi-channel media streams
		kSessionError_OM_ERR_INVALID_CACHE_SIZE,//	OMFI_ERR: Stream cache size must be positive or zero
		kSessionError_OM_ERR_NOT_FILEMOB,		//	OMFI_ERR: Operation requires a file mob
		kSessionError_OM_ERR_TRANSLATE_SAMPLE_SIZE,	//	OMFI_ERR: Codec can't translate to/from that sample size
		kSessionError_OM_ERR_TRANSLATE_NON_INTEGRAL_RATE,	//	OMFI_ERR: Codec can't translate to/from rates which are not multiples
		kSessionError_OM_ERR_MISSING_MEDIA_REP,	//	OMFI_ERR: Media representation not present in the mob
		kSessionError_OM_ERR_NOT_LONGWORD,		//	OMFI_ERR: Buffer must be longword aligned for this translation
		kSessionError_OM_ERR_XFER_DUPCH,		//	OMFI_ERR: Cannot specify the same channel twice in multi-xfers
		kSessionError_OM_ERR_MEDIA_NOT_INIT,	//	OMFI_ERR: omfmInit() must be called before making this call
		kSessionError_OM_ERR_BLOCKING_SIZE,		//	OMFI_ERR: Blocking size must be >= 0 bytes
		kSessionError_OM_ERR_WRONG_MEDIATYPE,	//	OMFI_ERR: Incorrect media type for this operation
		kSessionError_OM_ERR_MULTI_WRITELEN,	//	OMFI_ERR: Writelengths in a writeMultiple must be uniform
		kSessionError_OM_ERR_STREAM_REOPEN,		//	OMFI_ERROR: Stream reopened without being closed
		kSessionError_OM_ERR_TOO_MANY_FMT_OPS,	//	OMFI_ERROR: Too many format specifiers for this codec
		kSessionError_OM_ERR_MEDIASTREAM_NOTALLOWED,	//	OMFI_ERR: An object with a media stream datakind is not allowed
		kSessionError_OM_ERR_STILLFRAME_BADLENGTH,		//	OMFI_ERR: Length of a still frame in a media group must be 1
		kSessionError_OM_ERR_DATA_NONCONTIG,	//	OMFI_ERR: Calling this function now will produce non-contiguous media data
		kSessionError_OM_ERR_OPLIST_OVERFLOW,	//	OMFI_ERR: Operation list overflow
		kSessionError_OM_ERR_STREAM_CLOSED,		//	OMFI_ERR: Stream must be open for this operation
		kSessionError_OM_ERR_USE_MULTI_CREATE,	//	OMFI_ERR: Use multiCreate to create this many interleaved channels
		kSessionError_OM_ERR_MEDIA_OPENMODE,	//	OMFI_ERR: Media object opened in wrong mode (readonly vs. readwrite)
		kSessionError_OM_ERR_MEDIA_CANNOT_CLOSE,//	OMFI_ERR: No proc to close media
		kSessionError_OM_ERR_XFER_NOT_BYTES,	//	OMFI_ERR: Sample transfers must be an integral number of bytes
		kSessionError_OM_ERR_ZERO_SAMPLESIZE,	//	OMFI_ERR: Sample size of zero not allowed
		kSessionError_OM_ERR_ZERO_PIXELSIZE,	//	OMFI_ERR: Pixel size of zero not allowed
		/* Codec Error Codes */
		kSessionError_OM_ERR_CODEC_INVALID,		//	CODEC invalid or not loaded
		kSessionError_OM_ERR_INVALID_OP_CODEC,	//	OMFI_ERR: Operation not valid on this codec
		kSessionError_OM_ERR_BAD_CODEC_REV,		//	OMFI_ERR: Out of date codec
		kSessionError_OM_ERR_CODEC_CHANNELS,	//	OMFI_ERR: Channel out of range for codec
		kSessionError_OM_ERR_BAD_VARIETY,		//	OMFI_ERR: Badly formed codec variety string
		kSessionError_OM_ERR_CODEC_NAME_SIZE,	//	OMFI_ERR: Codec name string too large
		/* Image Error Codes */
		kSessionError_OM_ERR_TIFFVERSION,		//	OMFI_ERR: Error reading tiff version
		kSessionError_OM_ERR_BADTIFFCOUNT,		//	OMFI_ERR: Video: TIFF count less than 1
		kSessionError_OM_ERR_24BITVIDEO,		//	OMFI_ERR: 24 Bit (8-8-8) video only
		kSessionError_OM_ERR_JPEGBASELINE,		//	OMFI_ERR: Only baseline JPEG allowed in OMF files
		kSessionError_OM_ERR_BADJPEGINFO,		//	OMFI_ERR: JPEG TIFF fields not allowed without COMPRESSION == JPEG
		kSessionError_OM_ERR_BADQTABLE,			//	OMFI_ERR: Bad JPEG Quantization Table
		kSessionError_OM_ERR_BADACTABLE,		//	OMFI_ERR: Bad JPEG AC Huffman Table
		kSessionError_OM_ERR_BADDCTABLE,		//	OMFI_ERR: Bad JPEG DC Huffman Table
		kSessionError_OM_ERR_NOFRAMEINDEX,		//	OMFI_ERR: No JPEG Video Frame Index
		kSessionError_OM_ERR_BADFRAMEOFFSET,	//	OMFI_ERR: Frame Index offset out of range
		kSessionError_OM_ERR_JPEGPCM,			//	OMFI_ERR: OMJPEG.c: put_color_map called
		kSessionError_OM_ERR_JPEGDISABLED,		//	OMFI_ERR: JPEG codec disabled
		kSessionError_OM_ERR_JPEGPROBLEM,		//	OMFI_ERR: Unspecified JPEG codec problem
		kSessionError_OM_ERR_BADEXPORTPIXFORM,	//	OMFI_ERR: Unrecognized Pixel Format
		kSessionError_OM_ERR_BADEXPORTLAYOUT,	//	OMFI_ERR: Unrecognized Frame Layout
		kSessionError_OM_ERR_BADRWLINES,		//	OMFI_ERR: Read/Write Lines only enabled for common video format
		/* Audio Error Codes */
		kSessionError_OM_ERR_BADAIFCDATA,		//	OMFI_ERR: Error reading AIFC data
		kSessionError_OM_ERR_BADWAVEDATA,		//	OMFI_ERR: Error reading WAVE data
		kSessionError_OM_ERR_NOAUDIOCONV,		//	OMFI_ERR: Audio Read Samples: Can't convert to requested sample size

		/*** OBJECT Error Codes ***/
		kSessionError_OM_ERR_NULLOBJECT,		//	OMFI_ERR: Null Object not allowed
		kSessionError_OM_ERR_BADINDEX,			//	OMFI_ERR: Array Index Out of Range
		kSessionError_OM_ERR_INVALID_LINKAGE,	//	OMFI_ERR: Invalid object attached to property
		kSessionError_OM_ERR_BAD_PROP,			//	OMFI_ERR: Property code out of range
		kSessionError_OM_ERR_BAD_TYPE,			//	OMFI_ERR: Type code out of range
		kSessionError_OM_ERR_SWAB,				//	OMFI_ERR: Cannot swab that data size
		kSessionError_OM_ERR_END_OF_DATA,		//	OMFI_ERR: Read past end of data
		kSessionError_OM_ERR_PROP_NOT_PRESENT,	//	OMFI_ERR: Property missing from the file
		kSessionError_OM_ERR_INVALID_DATAKIND,	//	OMFI_ERR: Datakind invalid or nonexistant
		kSessionError_OM_ERR_DATAKIND_EXIST,	//	OMFI_ERR: A Datakind Definition with this ID already exists
		kSessionError_OM_ERR_TOO_MANY_TYPES,	//	OMFI_ERR: Too many types for a single property
		/*** MOB Error Codes ***/
		/* General Segment Error Codes */
		kSessionError_OM_ERR_NOT_SOURCE_CLIP,	//	OMFI_ERR: This property must be a Source Clip
		kSessionError_OM_ERR_FILL_FOUND,		//	OMFI_ERR: An unexpected fill property was found
		kSessionError_OM_ERR_BAD_LENGTH,		//	OMFI_ERR: Segment has an illegal length
		kSessionError_OM_ERR_BADRATE,			//	OMFI_ERR: Illegal value for edit rate
		kSessionError_OM_ERR_INVALID_ROUNDING,	//	OMFI_ERR: Editrate rounding must be either Floor or Ceiling
		kSessionError_OM_ERR_PULLDOWN_DIRECTION,//	OMFI_ERR: Illegal pulldown direction
		kSessionError_OM_ERR_PULLDOWN_FUNC,		//	OMFI_ERR: use omfmMobAddPulldownRef() instead of omfmMobAddPhysSourceRef() for pulldown
		kSessionError_OM_ERR_NOT_COMPOSITION,	//	OMFI_ERR: This property must be a Composition
		/* Timecode Error Codes */
		kSessionError_OM_ERR_TIMECODE_NOT_FOUND,//	OMFI_ERR: Timecode was not found in the mob chain
		kSessionError_OM_ERR_NO_TIMECODE,		//	OMFI_ERR: Cannot find timecode on given track
		kSessionError_OM_ERR_INVALID_TIMECODE,	//	OMFI_ERR: Timecode value is invalid
		/* Track Error Codes */
		kSessionError_OM_ERR_TRACK_NOT_FOUND,	//	OMFI_ERR: Track not found
		kSessionError_OM_ERR_BAD_SLOTLENGTH,	//	OMFI_ERR: Bad Slot Length
		kSessionError_OM_ERR_MISSING_TRACKID,	//	OMFI_ERR: TrackID not present in the mob
		kSessionError_OM_ERR_TRACK_EXISTS,		//	OMFI_ERR: A Track with this trackID already exists
		kSessionError_OM_ERR_NOT_A_TRACK,		//	OMFI_ERR: This function requires a track, not a mob slot.
		/* MOBJ Error Codes */
		kSessionError_OM_ERR_MOB_NOT_FOUND,		//	OMFI_ERR: Mob does not exist in this file
		kSessionError_OM_ERR_NO_MORE_MOBS,		//	OMFI_ERR: The end of the mob chain has been reached
		kSessionError_OM_ERR_DUPLICATE_MOBID,	//	OMFI_ERR: MobID already exists in the file
		kSessionError_OM_ERR_MISSING_MOBID,		//	OMFI_ERR: MobID not present in the file
		/* Effect Error Codes */
		kSessionError_OM_ERR_EFFECTDEF_EXIST,	//	OMFI_ERR: An Effect Definition with this Effect ID already exists
		kSessionError_OM_ERR_INVALID_EFFECTDEF,	//	OMFI_ERR: Effect Definition invalid or nonexistant
		kSessionError_OM_ERR_INVALID_EFFECT,	//	OMFI_ERR: Effect is invalid or non-existent
		kSessionError_OM_ERR_INVALID_EFFECTARG,	//	OMFI_ERR: The given effect argument is not valid for this effect
		kSessionError_OM_ERR_INVALID_CVAL,		//	OMFI_ERR: Constant value is invalid or nonexistent
		kSessionError_OM_ERR_RENDER_NOT_FOUND,	//	OMFI_ERR: Effect Rendering does not exist
		/* Iterator Error Codes */
		kSessionError_OM_ERR_BAD_ITHDL,			//	OMFI_ERR: Bad Iterator handle
		kSessionError_OM_ERR_NO_MORE_OBJECTS,	//	OMFI_ERR: No More Objects
		kSessionError_OM_ERR_ITER_WRONG_TYPE,	//	OMFI_ERR: Wrong iterator type for this function
		kSessionError_OM_ERR_INVALID_SEARCH_CRIT,	//	OMFI_ERR: Invalid search criteria for this kind of iterator
		kSessionError_OM_ERR_INTERNAL_ITERATOR,	//	OMFI_INTERNAL_ERR: Internal error with iterator
		kSessionError_OM_ERR_BAD_SRCH_ITER,		//	OMFI_ERR: This iterator handle must be allocated by omfiMobOpenSearch()
		/* Traversal Error Codes */
		kSessionError_OM_ERR_NULL_MATCHFUNC,	//	OMFI_ERR: Match function to traversal routine is null
		kSessionError_OM_ERR_NULL_CALLBACKFUNC,	//	OMFI_ERR: Callback function to traversal routine is null
		kSessionError_OM_ERR_TRAVERSAL_NOT_POSS,//	OMFI_ERR: Mob traversal failed
		kSessionError_OM_ERR_PARSE_EFFECT_AMBIGUOUS,	//	OMFI_ERR: Need more information to parse further through an effect
		/* Transition Error Codes */
		kSessionError_OM_ERR_INVALID_TRAN_EFFECT,	//	OMFI_ERR: Effect is not a transition effect
		kSessionError_OM_ERR_ADJACENT_TRAN,		//	OMFI_ERR: Adjacent transitions in a sequence are illegal
		kSessionError_OM_ERR_LEADING_TRAN,		//	OMFI_ERR: Beginning a sequence with a transition is illegal
		kSessionError_OM_ERR_INSUFF_TRAN_MATERIAL,	//	OMFI_ERR: Not enough material as input to transition

		/*** SIMPLE COMPOSITION Error Codes ***/
		kSessionError_OM_ERR_BAD_STRACKHDL,			//	OMFI_ERR: Bad Simple Track handle
		kSessionError_OM_ERR_STRACK_APPEND_ILLEGAL,	//	OMFI_ERR: This track does not contain a sequence, appending is illegal

		/*** GENERIC Error Codes ***/
		kSessionError_OM_ERR_NOMEMORY,			//	OMFI_ERR: Memory allocation failed, no more heap memory
		kSessionError_OM_ERR_OFFSET_SIZE,		//	OMFI_ERR: 64-bit truncation error
		kSessionError_OM_ERR_INTERNAL_NEG64,	//	OMFI_ERR: Negative 64-bit number
		kSessionError_OM_ERR_OVERFLOW64,		//	OMFI_ERR: Overflow on a 64-bit operation
		kSessionError_OM_ERR_NOT_IN_15,			//	OMFI_ERR: Function not available in 1.x compatability mode
		kSessionError_OM_ERR_NOT_IN_20,			//	OMFI_ERR: Function not available in 2.x native mode
		kSessionError_OM_ERR_NOT_IMPLEMENTED,	//	OMFI_ERR: Not Implemented
		kSessionError_OM_ERR_NULL_PARAM,		//	OMFI_ERR: NULL Actual parameter to function call
		kSessionError_OM_ERR_ZERO_DIVIDE,		//	OMFI_ERR: Divide by zero
		/*** SEMANTIC CHECKING Error Codes ***/
		kSessionError_OM_ERR_REQUIRED_POSITIVE,	//	OMFI_ERR: Value should be positive or zero
		kSessionError_OM_ERR_INVALID_TRACKKIND,	//	OMFI_ERR: Invalid Track Kind
		kSessionError_OM_ERR_INVALID_EDGETYPE,	//	OMFI_ERR: Invalid Edge Code Format Kind
		kSessionError_OM_ERR_INVALID_FILMTYPE,	//	OMFI_ERR: Invalid Film Type
		kSessionError_OM_ERR_INVALID_TAPECASETYPE,		//	OMFI_ERR: Invalid Tape Case Type
		kSessionError_OM_ERR_INVALID_VIDEOSIGNALTYPE,	//	OMFI_ERR: Invalid Video Signal Type
		kSessionError_OM_ERR_INVALID_TAPEFORMATTYPE,	//	OMFI_ERR: Invalid Tape Format Type
		kSessionError_OM_ERR_INVALID_EDITHINT,	//	OMFI_ERR: Invalid Effect Edit Hint
		kSessionError_OM_ERR_INVALID_INTERPKIND,//	OMFI_ERR: Invalid Effect Interpolation Kind
		kSessionError_OM_ERR_INVALID_MOBTYPE,	//	OMFI_ERR: Invalid Mob Type
		kSessionError_OM_ERR_INVALID_TRACK_REF,	//	OMFI_ERR: Positive Relative Track Reference not allowed
		kSessionError_OM_ERR_INVALID_OBJ,		//	OMFI_ERR: Invalid object for this operation
		kSessionError_OM_ERR_BAD_VIRTUAL_CREATE,//	OMFI_ERR: Creation of virtual objects not allowed
		kSessionError_OM_ERR_INVALID_CLASS_ID,	//	OMFI_ERR: Invalid Object Class ID
		kSessionError_OM_ERR_OBJECT_SEMANTIC,	//	OMFI_ERR: Failed a semantic check on an input obj
		kSessionError_OM_ERR_DATA_IN_SEMANTIC,	//	OMFI_ERR: Failed a semantic check on an input data
		kSessionError_OM_ERR_DATA_OUT_SEMANTIC,	//	OMFI_ERR: Failed a semantic check on an output data
		kSessionError_OM_ERR_TYPE_SEMANTIC,		//	OMFI_ERR: Property and type do not match
		kSessionError_OM_ERR_INVALID_ATTRIBUTEKIND,	//	OMFI_ERR: Invalid Attribute Kind
		kSessionError_OM_ERR_DATA_MDES_DISAGREE,	//	OMFI_ERR: Media descriptor summary data does not agree with media
		kSessionError_OM_ERR_CODEC_SEMANTIC_WARN,	//	OMFI_ERR: A semantic check warning occured when checking media
		kSessionError_OM_ERR_INVALID_BOOLTYPE,		//	OMFI_ERR: Invalid Boolean Value
		/*** INTERNAL Error Codes ***/
		kSessionError_OM_ERR_TABLE_DUP_KEY,		//	OMFI_INTERNAL_ERR: Duplicate Key detected in internal table
		kSessionError_OM_ERR_TABLE_MISSING_COMPARE,	//	OMFI_INTERNAL_ERR: Missing compare function on table
		kSessionError_OM_ERR_TABLE_BAD_HDL,		//	OMFI_INTERNAL_ERR: Bad table handle
		kSessionError_OM_ERR_TABLE_BAD_ITER,	//	OMFI_INTERNAL_ERR: Bad table iterator handle
		kSessionError_OM_ERR_BENTO_PROBLEM,		//	OMFI_ERR: Bento container error
		kSessionError_OM_ERR_BENTO_HANDLER,		//	OMFI_INTERNAL_ERR: Can't locate Bento handler
		kSessionError_OM_ERR_PROPID_MATCH,		//	OMFI_INTERNAL_ERR: Property ID code doesn't match between revs
		kSessionError_OM_ERR_INTERNAL_DIVIDE,	//	OMFI_ERR: Internal division error
		/*** Testing Error Codes ***/
		kSessionError_OM_ERR_TEST_FAILED,		//	OMFI_TESTING_ERR: Test Failed

		kSessionProgress_OMF_CheckingMediaFiles	= 3400,	//	Checking Media Files
		kSessionProgress_OMF_ConvertingMediaFile,		//	Converting Media File
		kSessionProgress_OMF_ConvertingOMFFile,			//	Converting OMF File
		kSessionProgress_OMF_ConvertingSoundFile,		//	Converting Sound File
		kSessionProgress_OMF_ExtractingSoundData,		//	Extracting Sound Data
		kSessionProgress_OMF_MakingCompositionTracks,	//	Making Composition Tracks
		kSessionProgress_OMF_MakingGainControlPoints,	//	Making Gain Control Points
		kSessionProgress_OMF_MakingMediaObjEncapsulate,	//	Making Media Objects (Encapsulating Audio)
		kSessionProgress_OMF_MakingMediaObjReference,	//	Making Media Object References
		kSessionProgress_OMF_MakingTapeReels,			//	Making Tape Reels
		kSessionProgress_OMF_FinishingExport,			//	Finishing OMF Export
	
		// Warnings are non-fatal conditions where the operation
		// is not aborted, but continues.

		kSessionWarning_OMF_FailureOpeningFile	= 3500,	//	Failure opening file.
		kSessionWarning_OMF_FileHasNoSoundData,			//	File has no sound data.
		kSessionWarning_OMF_NoMediaFound,				//	No Media Found.
		kSessionWarning_OMF_CreateAIFFFileFailed,		//	Failed to create AIFF file.
		kSessionWarning_OMF_EncapsulatedStereo,			//	Encapsulated stereo files within OMF files are not supported.
		kSessionWarning_OMF_EncapsulatedWave,			//	Encapsulated WAV files within OMF files are not supported.
		kSessionWarning_OMF_NoTracksInImportFile,		//	There are no tracks in this OMF file.
		kSessionWarning_OMF_InsufficientSourceMedia,	//	Clip duration is longer than source.
		kSessionWarning_OMF_NegativeStartOffset,		//	Start time offset is negative. This will be changed to zero.
		kSessionWarning_OMF_MissingSourceFile,			//	A source file is missing.
		kSessionWarning_OMF_IncompatibleOMF,			//	This OMF might not be compatible with Avid products.
	};

} // namespace ases

#endif // AUDITION_SESSIONSDK_OMFSTRINGS_H
