/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2009 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef ADOBE_AUDITION_SESSION_INTERFACETEMPLATE_H
#define ADOBE_AUDITION_SESSION_INTERFACETEMPLATE_H

#include "AuditionSDK/Session/SessionSDK.h"
#include "AuditionSDK/Session/ISessionError.h"
#include "AuditionSDK/Session/ISessionGetPlugInInfo.h"
#include "AuditionSDK/Session/ISessionOpen.h"
#include "AuditionSDK/Session/IEditSession.h"
#include "AuditionSDK/Session/IQuerySession.h"
#include "AuditionSDK/Session/ISessionError.h"

namespace ases
{

	class SessionInterface
	{
	public:
		///
		SessionInterface()
		{
		}

		///
		virtual ~SessionInterface()
		{
		}

		///
		SessionResult EntryPoint(asdk::int32 inCommand, void* inInterface)
		{
			SetErrorInterface(NULL);

			switch (inCommand)
			{

			case kSessionInterfaceCommand_GetPlugInInfo:
			{
				ISessionGetPlugInInfo* plugInInfo = (ISessionGetPlugInInfo*)inInterface;
				if (!plugInInfo)
				{
					return kSessionInterfaceReturnCode_ParameterOutOfRange;
				}
				plugInInfo->SetPluginInterfaceVersion(kSessionInterfaceVersionMajor, kSessionInterfaceVersionMinor);
				return GetPlugInInfo(plugInInfo);
			}

			case kSessionInterfaceCommand_Initialize:
			{
				return Initialize();
			}

			case kSessionInterfaceCommand_Terminate:
			{
				return Terminate();
			}

			case kSessionInterfaceCommand_Open:
			{
				ISessionOpen* sessionOpen = (ISessionOpen*)inInterface;
				if (!sessionOpen)
				{
					return kSessionInterfaceReturnCode_ParameterOutOfRange;
				}
				return SessionOpen(sessionOpen);
			}

			case kSessionInterfaceCommand_Read:
			{
				IEditSession* sessionInterface = (IEditSession*)(inInterface);

				if (!sessionInterface)
				{
					return kSessionInterfaceReturnCode_ParameterOutOfRange;
				}
				return ReadSession(sessionInterface);
			}

			case kSessionInterfaceCommand_Write:
			{
				IQuerySession* sessionInterface = (IQuerySession*)(inInterface);
				if (!sessionInterface)
				{
					return kSessionInterfaceReturnCode_ParameterOutOfRange;
				}
				SetErrorInterface(sessionInterface->GetErrorInterface());
				return WriteSession(sessionInterface);
			}

			default:
				return kSessionInterfaceReturnCode_UnknownCommand;

			}
		}

	protected:

		///
		virtual SessionResult GetPlugInInfo(ISessionGetPlugInInfo*)
		{
			return kSessionInterfaceReturnCode_Success;
		}

		///
		virtual SessionResult Initialize()
		{
			return kSessionInterfaceReturnCode_Success;
		}

		///
		virtual SessionResult Terminate()
		{
			return kSessionInterfaceReturnCode_Success;
		}

		//
		///
		virtual SessionResult SessionOpen(ISessionOpen* inOpenInterface)
		{
			return kSessionInterfaceReturnCode_UnsupportedCommand;
		}

		///
		virtual SessionResult ReadSession(IEditSession* inReadInterface)
		{
			return kSessionInterfaceReturnCode_UnsupportedCommand;
		}

		///
		virtual SessionResult WriteSession(IQuerySession* inWriteInterface)
		{
			return kSessionInterfaceReturnCode_UnsupportedCommand;
		}


	protected:
		///
		void SetErrorInterface(ISessionErrorPtr inErrorInterface)
		{
			mErrorInterface = inErrorInterface;
		}

		/// Return extended error information if we can.
		void SetErrorString(const asdk::uniChar16* inErrorString)
		{
			if (mErrorInterface)
			{
				mErrorInterface->SetCustomErrorString(inErrorString);
			}
		}

		void AddWarning(const asdk::uniChar16*  inWarningText)
		{
			if (mErrorInterface)
			{
				mErrorInterface->AddCustomWarningString(inWarningText);
			}
		}

		ISessionErrorPtr	mErrorInterface;
		
	}; // SessionInterface

} // namespace ases

#endif // ADOBE_AUDITION_SESSION_INTERFACETEMPLATE_H
