/**************************************************************************
*
* ADOBE CONFIDENTIAL
* ___________________
*
*  Copyright 2008 Adobe Systems Incorporated
*  All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* Adobe Systems Incorporated  and its suppliers,  if any.  The intellectual 
* and technical concepts contained herein are proprietary to  Adobe Systems 
* Incorporated  and its suppliers  and may be  covered by U.S.  and Foreign 
* Patents,patents in process,and are protected by trade secret or copyright 
* law.  Dissemination of this  information or reproduction of this material
* is strictly  forbidden  unless prior written permission is  obtained from 
* Adobe Systems Incorporated.
**************************************************************************/

#ifndef AUDITION_SESSIONSDK_SESSIONSDK_H
#define AUDITION_SESSIONSDK_SESSIONSDK_H

#include "AuditionSDK/ASDKTypes.h"

namespace ases
{
	typedef asdk::int32 SessionResult;

	// This is the type of the single interface function to an session plug-in.
	typedef SessionResult (*SessionInterfaceFunc)(asdk::int32 inCommand,void* inInterface);

	// These are the commands passed into the interface function as inCommand.
	enum SessionInterfaceCommand
	{
		kSessionInterfaceCommand_GetPlugInInfo				= 0,	// kSessionInterfaceCommand_GetSessionInfo, The first call made to a plug-in module
																// NULL, 
																// SessionGetSessionInfoInterface.

		kSessionInterfaceCommand_Initialize					= 1,	// kSessionInterfaceCommand_Initialize, The second call made to a plug-in module
																// NULL, 
																// NULL.

		kSessionInterfaceCommand_Terminate					= 2,	// kSessionInterfaceCommand_Terminate, The last call made to a plug-in module
																// NULL, 
																// NULL.

		kSessionInterfaceCommand_Open						= 3,	// kSessionInterfaceCommand_Open, 
																// NULL, 
																// SessionInterface.

		kSessionInterfaceCommand_Read						= 4,	// kSessionInterfaceCommand_Read, 
																// NULL, 
																// SessionInterface.

		kSessionInterfaceCommand_Write						= 5	// kSessionInterfaceCommand_Write, 
																// NULL, 
																// SessionInterface.
	};

	// an SessionResult can be one of these values, or some other value of the plug-in's own choosing.
	enum SessionInterfaceReturnCode
	{
		kSessionInterfaceReturnCode_Success					= 0,

		kSessionInterfaceReturnCode_GeneralError			= -1,	
		kSessionInterfaceReturnCode_UnknownCommand			= -2,	// The plug-in does not know about the given command.
		kSessionInterfaceReturnCode_UnsupportedCommand		= -3,	// This command is not supported by this plug-in.

		kSessionInterfaceReturnCode_CorruptOrUnsupported	= -4,	// The file is either corrupt or using an unsupported format.
		kSessionInterfaceReturnCode_NoSuchItem				= -5,	// A request was given for an unknown item. (e.g. via kSessionInterfaceCommand_ReadMetadata)
		kSessionInterfaceReturnCode_ParameterOutOfRange		= -6,	// A size or other parameter is beyond a valid range.
		kSessionInterfaceReturnCode_PlugInException			= -7,	// The plug-in generated an exception.

		kSessionInterfaceReturnCode_UnsupportedFormat		= -8,	// The given format is not supported.

		kSessionInterfaceReturnCode_DecoderError			= -9,	// There was an error during the decode process.
		kSessionInterfaceReturnCode_EncoderError			= -10,	// There was an error during the encode process.	
	};


	// Session SDK version 1.0	= Audition CS5.5 (4.0) through Audition CC 2014.2 (7.2)
	// Session SDK version 1.1	= Audition CC 2015 (8.0)
	// Session SDK version 1.2	= Audition CC 2015.1 (8.1)
	// Session SDK version 1.3	= Audition CC 2015.2 (9.2)
	const asdk::int32 kSessionInterfaceVersionMajor = 1;					// Pass this value in SessionGetSessionInfoInterface::SetInterfaceVersion()
	const asdk::int32 kSessionInterfaceVersionMinor = 3;					// Pass this value in SessionGetSessionInfoInterface::SetInterfaceVersion()

} // namespace ases

#endif // AUDITION_SESSIONSDK_SESSIONSDK_H
